==> moyoung_ble_plugin-1.0.19.tar.gz: android/src/main/java/com/moyoung/moyoung_ble_plugin/event/CameraHandler.java <==
package com.moyoung.moyoung_ble_plugin.event;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.conn.listener.CRPCameraOperationListener;
import com.moyoung.moyoung_ble_plugin.base.BaseConnectionEventChannelHandler;
import com.moyoung.moyoung_ble_plugin.common.GsonUtils;
import com.moyoung.moyoung_ble_plugin.common.MyLog;
import com.moyoung.moyoung_ble_plugin.model.CameraBean;

import io.flutter.plugin.common.MethodCall;

public class CameraHandler extends BaseConnectionEventChannelHandler {
    @Override
    public void setConnListener(CRPBleConnection connection, MethodCall call) {
        connection.setCameraOperationListener((new CRPCameraOperationListener() {
            @Override
            public void onTakePhoto() {
                if (eventSink == null) {
                    return;
                }
                CameraBean cameraBean = new CameraBean(CameraBean.TAKEPHOTOSTATE);
                cameraBean.setTakePhoto("takePhoto");
                String cameraStr = GsonUtils.get().toJson(cameraBean, CameraBean.class);
                activity.runOnUiThread(() -> eventSink.success(cameraStr));
            }

            @Override
            public void onDelayTaking(int delayTime) {
                if (eventSink == null) {
                    return;
                }
                CameraBean cameraBean = new CameraBean(CameraBean.DELAYTAKINGSTATE);
                cameraBean.setDelayTime(delayTime);
                String cameraStr = GsonUtils.get().toJson(cameraBean, CameraBean.class);
                activity.runOnUiThread(() -> eventSink.success(cameraStr));
            }
        }));
    }

}

==> moyoung_ble_plugin-1.0.23.tar.gz: android/src/main/java/com/moyoung/moyoung_ble_plugin/event/CameraHandler.java <==
package com.moyoung.moyoung_ble_plugin.event;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.conn.listener.CRPCameraOperationListener;
import com.moyoung.moyoung_ble_plugin.base.BaseConnectionEventChannelHandler;
import com.moyoung.moyoung_ble_plugin.common.GsonUtils;
import com.moyoung.moyoung_ble_plugin.common.MyLog;
import com.moyoung.moyoung_ble_plugin.model.CameraBean;

import io.flutter.plugin.common.MethodCall;

public class CameraHandler extends BaseConnectionEventChannelHandler {
    @Override
    public void setConnListener(CRPBleConnection connection, MethodCall call) {
        connection.setCameraOperationListener((new CRPCameraOperationListener() {
            @Override
            public void onTakePhoto() {
//                if (eventSink == null) {
//                    return;
//                }
//                CameraBean cameraBean = new CameraBean(CameraBean.TAKEPHOTOSTATE);
//                cameraBean.setTakePhoto("takePhoto");
//                String cameraStr = GsonUtils.get().toJson(cameraBean, CameraBean.class);
//                activity.runOnUiThread(() -> eventSink.success(cameraStr));
                connection.queryDelayTaking();
            }

            @Override
            public void onDelayTaking(int delayTime) {
                if (eventSink == null) {
                    return;
                }
                CameraBean cameraBean = new CameraBean(CameraBean.DELAYTAKINGSTATE);
                cameraBean.setDelayTime(delayTime);
                cameraBean.setTakePhoto("takePhoto");
                String cameraStr = GsonUtils.get().toJson(cameraBean, CameraBean.class);
                activity.runOnUiThread(() -> eventSink.success(cameraStr));
            }
        }));
    }

}
